# core.config

## AudioBlock

::: fastaudio.core.config.AudioBlock
    :docstring:
    :members:

## preprocess_audio_folder

::: fastaudio.core.config.preprocess_audio_folder
    :docstring:
    :members:

## PreprocessAudio

::: fastaudio.core.config.PreprocessAudio
    :docstring:
    :members:

## AudioConfig

::: fastaudio.core.config.AudioConfig
    :docstring:
    :members:
